==> modelscope-1.4.0.tar.gz: modelscope-1.4.0/modelscope/models/cv/__init__.py <==
# Copyright (c) Alibaba, Inc. and its affiliates.

# yapf: disable
from . import (action_recognition, animal_recognition, bad_image_detecting,
               body_2d_keypoints, body_3d_keypoints, cartoon,
               cmdssl_video_embedding, controllable_image_generation,
               crowd_counting, face_2d_keypoints, face_detection,
               face_generation, face_reconstruction, human_reconstruction,
               human_wholebody_keypoint, image_classification,
               image_color_enhance, image_colorization, image_defrcn_fewshot,
               image_denoise, image_inpainting, image_instance_segmentation,
               image_matching, image_mvs_depth_estimation,
               image_panoptic_segmentation, image_portrait_enhancement,
               image_probing_model, image_quality_assessment_degradation,
               image_quality_assessment_man, image_quality_assessment_mos,
               image_reid_person, image_restoration,
               image_semantic_segmentation, image_to_image_generation,
               image_to_image_translation, language_guided_video_summarization,
               movie_scene_segmentation, object_detection,
               panorama_depth_estimation, pointcloud_sceneflow_estimation,
               product_retrieval_embedding,
               referring_video_object_segmentation,
               robust_image_classification, salient_detection,
               shop_segmentation, stream_yolo, super_resolution,
               table_recognition, video_deinterlace, video_frame_interpolation,
               video_object_segmentation, video_panoptic_segmentation,
               video_single_object_tracking, video_stabilization,
               video_summarization, video_super_resolution, vidt, virual_tryon,
               vision_middleware, vop_retrieval)

# yapf: enable

==> modelscope-1.5.2.tar.gz: modelscope-1.5.2/modelscope/models/cv/__init__.py <==
# Copyright (c) Alibaba, Inc. and its affiliates.

# yapf: disable
from . import (action_recognition, animal_recognition, bad_image_detecting,
               body_2d_keypoints, body_3d_keypoints, cartoon,
               cmdssl_video_embedding, controllable_image_generation,
               crowd_counting, face_2d_keypoints, face_detection,
               face_generation, face_reconstruction, human_reconstruction,
               human_wholebody_keypoint, image_classification,
               image_color_enhance, image_colorization, image_defrcn_fewshot,
               image_denoise, image_inpainting, image_instance_segmentation,
               image_matching, image_mvs_depth_estimation,
               image_panoptic_segmentation, image_portrait_enhancement,
               image_probing_model, image_quality_assessment_degradation,
               image_quality_assessment_man, image_quality_assessment_mos,
               image_reid_person, image_restoration,
               image_semantic_segmentation, image_to_image_generation,
               image_to_image_translation, language_guided_video_summarization,
               movie_scene_segmentation, object_detection,
               panorama_depth_estimation, pedestrian_attribute_recognition,
               pointcloud_sceneflow_estimation, product_retrieval_embedding,
               referring_video_object_segmentation,
               robust_image_classification, salient_detection,
               shop_segmentation, stream_yolo, super_resolution,
               table_recognition, video_deinterlace, video_frame_interpolation,
               video_object_segmentation, video_panoptic_segmentation,
               video_single_object_tracking, video_stabilization,
               video_summarization, video_super_resolution, vidt, virual_tryon,
               vision_middleware, vop_retrieval)

# yapf: enable
